==> apache-cxf-3.5.9-src.zip: apache-cxf-3.5.9-src/systests/transport-jms/src/test/java/org/apache/cxf/jms/testsuite/services/GreeterSpecWithPortError.java <==
/**
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements. See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership. The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied. See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.cxf.jms.testsuite.services;

import org.apache.cxf.jms_greeter.JMSGreeterPortType;

@javax.jws.WebService(portName = "GreeterPort2",
                      serviceName = "JMSGreeterService2",
                      targetNamespace = "http://cxf.apache.org/jms_greeter",
                      endpointInterface = "org.apache.cxf.jms_greeter.JMSGreeterPortType",
                      wsdlLocation = "testutils/jms_spec_test.wsdl")
public class GreeterSpecWithPortError implements JMSGreeterPortType {

    public String greetMe(String me) {
        //System.out.println("Executing operation greetMe");
        //System.out.println("Message received: " + me + "\n");
        return "Hello " + me;
    }

    public String sayHi() {
        //System.out.println("Executing operation sayHi" + "\n");
        return "Bonjour";
    }

    public void greetMeOneWay(String me) {
        //System.out.println("Executing operation greetMeOneWay\n");
        //System.out.println("Hello there " + me);
    }
}

==> apache-cxf-4.0.10-src.zip: apache-cxf-4.0.10-src/systests/transport-jms/src/test/java/org/apache/cxf/jms/testsuite/services/GreeterSpecWithPortError.java <==
/**
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements. See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership. The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied. See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.cxf.jms.testsuite.services;

import org.apache.cxf.jms_greeter.JMSGreeterPortType;

@jakarta.jws.WebService(portName = "GreeterPort2",
                      serviceName = "JMSGreeterService2",
                      targetNamespace = "http://cxf.apache.org/jms_greeter",
                      endpointInterface = "org.apache.cxf.jms_greeter.JMSGreeterPortType",
                      wsdlLocation = "testutils/jms_spec_test.wsdl")
public class GreeterSpecWithPortError implements JMSGreeterPortType {

    public String greetMe(String me) {
        //System.out.println("Executing operation greetMe");
        //System.out.println("Message received: " + me + "\n");
        return "Hello " + me;
    }

    public String sayHi() {
        //System.out.println("Executing operation sayHi" + "\n");
        return "Bonjour";
    }

    public void greetMeOneWay(String me) {
        //System.out.println("Executing operation greetMeOneWay\n");
        //System.out.println("Hello there " + me);
    }
}
